#!/usr/bin/env python3
"""
A music streaming application.
"""
from aiohttp import web
import jinja2
import aiohttp_jinja2
from aiohttp_jinja2 import render_template
import uvloop

import config
import buckler_aiohttp

uvloop.install()
routes = web.RouteTableDef()

@routes.get('/', name='index')
async def index(request):
	"""The index page."""
	return render_template('index.html', request, {})


async def init_app():
	"""Initializes the application."""
	app = web.Application(middlewares=[buckler_aiohttp.buckler_session])
	aiohttp_jinja2.setup(
		app,
		trim_blocks=True,
		lstrip_blocks=True,
		undefined=jinja2.StrictUndefined,
		loader=jinja2.FileSystemLoader('templates'),
	)

	app.router.add_routes(routes)

	app_wrap = web.Application()
	app_wrap.add_subapp(config.url_prefix, app)
	return app_wrap


if __name__ == "__main__":
	app = init_app()
	aiohttp.web.run_app(app, host='0.0.0.0', port=5500)
